setwd("/data/sPlot/users/Helge/HIDDEN")
library(tidyverse)
library(foreign)
library(gridExtra)
library(grid)
library(vegan)

source("99_HIDDEN_functions.R")
source("01b_MesobromionCluster.R")

####1.  Reimport data ################################ 
traits <- read_delim("_data/Mesobromion/traits.v2.10perc.txt", delim="\t")
traits.sign.cov <- read_delim("_data/Mesobromion/traits.v2.10perc.cov.sign.txt", delim="\t")
traits.sign.pa <- read_delim("_data/Mesobromion/traits.v2.10perc.pa.sign.txt", delim="\t")
trait.labs <- data.frame(trait.name=colnames(traits)[-1]) %>% 
  left_join(read_delim("_data/Mesobromion/TraitLabels_Long.csv", delim=","), 
            by="trait.name") %>% 
  rownames_to_column("Trait.comb") %>% 
  mutate_at(.vars=vars(Short_english_name:Long_English_name), ~ifelse(is.na(.), trait.name, {.}))
env <- read_delim("_data/Mesobromion/env.v2.10perc.cov.txt", delim="\t")

traits <- traits %>% 
  as.data.frame() %>% 
#  filter(species0 %in% colnames(species)) %>% 
  mutate_if(~is.character(.), .funs=~as.factor(.)) %>% 
  column_to_rownames("species0")

traits.sign.cov <- traits.sign.cov %>% 
  as.data.frame() %>% 
  #  filter(species0 %in% colnames(species)) %>% 
  mutate_if(~is.character(.), .funs=~as.factor(.)) %>% 
  column_to_rownames("species0")

traits.sign.pa <- traits.sign.pa %>% 
  as.data.frame() %>% 
  #  filter(species0 %in% colnames(species)) %>% 
  mutate_if(~is.character(.), .funs=~as.factor(.)) %>% 
  column_to_rownames("species0")


## adapt trait labs to sign traits only
trait.labs.sign.cov <- trait.labs %>% 
  filter(trait.name %in% colnames(traits.sign.cov)) %>% 
  arrange(match(trait.name, colnames(traits.sign.cov))) %>% 
  rename(Trait.comb.new=Trait.comb) %>% 
  mutate(Trait.comb=1:8) %>% 
  dplyr::select(Trait.comb, everything(), -Trait.comb.new)
              
#rename trait based on short labels
colnames(traits) <- trait.labs$Short_english_name
colnames(traits.sign.cov) <- trait.labs.sign.cov$Short_english_name


##check traits
is.binary <- function(x){(all(na.omit(x) %in% 0:1))}

####1.1 Table S3 - Trait recap #####
trait.recap <- traits %>% 
  dplyr::select(-ends_with("1")) %>%  ## exclude two traits that shouldn't be there V_VER_present1 & V_VER_absent1
  mutate_if(.predicate = ~is.numeric(.), .funs=~round(.,3)) %>% 
  summarize_all(.funs = list(xxxType.of.variable=~ifelse(is.binary(.), "binary", 
                                ifelse(is.ordered(.), "ordered", 
                                       ifelse(is.numeric(.), "quantitative", 
                                              ifelse(is.factor(.), "nominal", NA)))),
                             xxxLevels=~(
                               ifelse(is.binary(.),
                                      paste(names(table(.)), "=", table(.), collapse="; "),
                                      ifelse(is.numeric(.), 
                                             paste(range(., na.rm=T), collapse=" - "),
                                             ifelse(is.factor(.), 
                                                    paste(levels(.), collapse=", "),
                                                    NA)))))) %>% 
  gather(key="Variable") %>% 
  separate(Variable, into = c("Variable", "feature"), sep="_xxx") %>% 
  spread(key=feature, value = value) %>% 
  rename(`Range/Levels`=Levels) %>% 
  mutate(Variable=factor(Variable, levels=colnames(traits))) %>% 
  arrange(Variable) %>% 
  left_join(trait.labs %>% 
              dplyr::select(Short_english_name, Long_English_name), 
            by=c("Variable" = "Short_english_name")) %>% 
  dplyr::select(Code=Variable, Variable=Long_English_name, everything())
  

write_csv(trait.recap, path="_derived/Mesobromion/Traits.recap.csv")  


###### 2. Import output from Cluster #### 
##### 2.1 Cover values ######
## traits onebyone
myfilelist0 <- list.files(path="_derived/Mesobromion/Cover/onebyone/", pattern="HIDDENcov-nona2_[0-9]+_.RData", full.names = T)
dataFiles0 = purrr::map(myfilelist0, function(x){get(load(x))})
#load("_derived/Mesobromion/PresAbs/HIDDEN_round_11.RData")
corXY.alone = bind_rows(dataFiles0) %>% 
  as.tbl() %>% 
  distinct()
corXY.alone.ci <- get.ci(corXY.alone)
corXY.alone.ci <- corXY.alone.ci %>% 
  mutate(trait1=Trait.comb) %>% 
  mutate_at(.vars=vars(trait1),
            .funs=~factor(., 
                          levels=trait.labs$Trait.comb, 
                          labels=trait.labs$Short_english_name)) %>% 
  arrange(ntraits, desc(Coef.obs)) %>% 
  dplyr::select(Trait.comb, Test, n, ntraits, everything()) %>% 
  mutate(Trait.comb=NA) %>% 
  mutate(run="alone")
  

### sequential trait combo
myfilelist1 <- list.files(path="_derived/Mesobromion/Cover/", pattern="HIDDENcov_round_[0-9]+.RData", full.names = T)
dataFiles1 = purrr::map(myfilelist1, function(x){get(load(x))})
#load("_derived/Mesobromion/PresAbs/HIDDEN_round_11.RData")
corXY.all = bind_rows(dataFiles1) %>% 
  as.tbl() %>% 
  distinct()
corXY.all.ci <- get.ci(corXY.all)
corXY.all.ci <- corXY.all.ci %>% 
  mutate(Trait.comb2=Trait.comb) %>% 
  separate(Trait.comb2, into=paste0("trait", 1:8)) %>% 
  mutate_at(.vars=vars(trait1:trait8),
            .funs=~factor(., 
                          levels=trait.labs$Trait.comb, 
                          labels=trait.labs$Short_english_name)) %>% 
  arrange(ntraits, desc(Coef.obs)) %>% 
  #filter(ntraits>1) %>% 
  dplyr::select(Trait.comb, Test, n, ntraits, everything()) %>% 
  mutate(run="seq")

### SEQUENTIAL of sign traits 
# myfilelist <- list.files(path="_derived/Mesobromion/Cover/_test1", pattern="HIDDENcov_round_[0-9]+.RData", full.names = T)
# dataFiles = purrr::map(myfilelist, function(x){get(load(x))})
# #load("_derived/Mesobromion/PresAbs/HIDDEN_round_11.RData")
# corXY.comb = bind_rows(dataFiles) %>% 
#   as.tbl()
# 
# corXY.comb.ci <- get.ci(corXY.comb)
# corXY.comb.ci <- corXY.comb.ci %>% 
#   mutate(Trait.comb2=Trait.comb) %>% 
#   #split strings of trait combinations and add labels
#   separate(Trait.comb2, into=paste0("trait", 1:8)) %>% 
#   mutate_at(.vars=vars(trait1:trait3),
#             .funs=~factor(., 
#                           levels=trait.labs$Trait.comb, 
#                           labels=trait.labs$Short_english_name)) %>% 
#   arrange(ntraits, Coef.obs) %>% 
#   dplyr::select(Trait.comb, Test, n, ntraits, everything())


rm( dataFiles0, dataFiles1)

### merge together
corXY.ci <- corXY.all.ci %>% 
  bind_rows(corXY.alone.ci) 


#### 2.1.2 One by one - Graph of r(XY)  ####
### list traits being significant when taken one by one
traits.sign.alone <- corXY.ci %>% 
  filter(run=="alone") %>% 
  filter(ntraits==1) %>% 
  filter(sign_plus==T) %>% 
  pull(trait1)
#"Height      Leaf_Anat   GF_Nanophan BL_Dur      VP_Fragm    SLA         LeafP       CSR       "

### Plot combinations one by one
mydata.byone <- corXY.ci %>% 
  filter(trait1 != c("V_VER_absent1", "V_VER_present1")) %>% ##delete traits that shouldn't be there
  filter(run=="alone") %>% 
  filter(ntraits==1)%>% 
  arrange(Coef.obs) %>% 
  mutate(seq=1:n())

(top.first <- ggplot(data=mydata.byone %>% 
                       mutate(sign_plus=fct_rev(as.factor(sign_plus)))) + 
  geom_segment(aes(x=q025, xend=q975, y=seq, yend=seq, 
                   col=sign_plus)) + 
  geom_point(aes(x=Coef.obs, y=seq), pch=15) + 
  scale_y_continuous(breaks=mydata.byone$seq, 
                     labels=mydata.byone$trait1, name=NULL)  +  
  scale_x_continuous(name="RD correlation") + 
  labs(color = "Significant") + 
  theme_bw() + 
  theme(panel.grid.minor = element_blank(),
        axis.text = element_text(size=7), 
        legend.position = c(0.8, 0.1))
)


ggsave(filename = "_pics/Fig4_TopFirstPredictors_CI_cov.png", dpi=400, 
       width=4, height=6, plot = top.first)

mydata <- corXY.ci %>% 
  filter(run=="seq") %>% 
  filter_at(.vars=vars(trait1:trait8), 
            all_vars(. %in% traits.sign.alone | is.na(.)))%>% 
  mutate(seq=1:n())

#### 2.1.3 All traits - (Huge) Graph of r(XY) (w/ combinations) ####
### filter combinations where all traits belong to traits.sign.alone

# allpredictors <- top.first %+% (mydata) +
#   scale_y_continuous(breaks=mydata$seq, 
#                      labels=NULL) + 
#   #                   labels=mydata$Trait.comb) + 
#   
#   theme_classic() + 
#   theme(axis.text.y = element_text(size=3))# + 
#  # facet_wrap(.~ntraits, scales = "free_y",  nrow=3)
# 
# ggsave(filename = "_pics/All_predictors_sign_individually_CI_faceted_0506.png", dpi=400, 
#        width=10, height=10, allpredictors)

######## 2.1.4 Best - Graph of r(XY) using best combination of traits at each level of interaction N  ########
### extract best combinations of traits
## ancillary function to get the best combination at a given Number of interactions
get.best <- function(x, N, labs){
  out <- x %>% 
    filter(ntraits==N) %>% 
    filter(sign_plus==TRUE) %>% 
    arrange(desc(Coef.obs)) %>% 
    slice(1) %>% 
    pull(Trait.comb)
  lab <- labs %>%
    filter(Trait.comb %in% strsplit(out, split = "_")[[1]]) %>% 
    pull(trait.name)
  return(list(Trait.comb=out, trait.name=lab))
}

top.one.by.one <- get.best(mydata, N=1, labs=trait.labs)

## Routine to extract the best combination at each level of interaction (up to max traits)
maxtraits <- 8
for(nn in 1:maxtraits){
  if(nn==1) {
    best.at.1 <- get.best(mydata, N=nn, labs=trait.labs)
    newdata <- mydata %>% 
      filter_at(.vars=vars(trait1:trait8),
                .vars_predicate = any_vars(. %in% best.at.1$trait.name | is.na(.))) 
    new.best.row <- newdata %>% 
      filter(Trait.comb==best.at.1$Trait.comb) 
    upper <- new.best.row$q975
    lower <- new.best.row$q025
    print(paste("new best at nn", nn, best.at.1$trait.name))
    best.progr <- best.at.1$Trait.comb
  }
  if(nn>1){
    better <- list()
    better$Trait.comb <- newdata %>% 
       filter(ntraits==nn) %>% 
       filter(q025>upper) %>% 
       arrange(desc(Coef.obs)) %>% 
       slice(1) %>% 
       pull(Trait.comb)

     if(length(better$Trait.comb>0)){
       better$trait.name <- trait.labs %>%
         filter(Trait.comb %in% strsplit(better$Trait.comb, split = "_")[[1]]) %>% 
         pull(trait.name)
       
       newdata <- newdata %>% 
         rowwise() %>% 
         mutate(nmatching= sum(unlist(strsplit(Trait.comb, "_")) %in% 
                                 unlist(strsplit(better$Trait.comb, "_")),
                                 na.rm=T)) %>% 
         ungroup() %>% 
         filter(nmatching==nn)
       
       new.best.row <- newdata %>% 
         filter(Trait.comb==better$Trait.comb) 
       upper <- new.best.row$q975
       lower <- new.best.row$q025
       print(paste("new best at nn", nn, paste(better$trait.name, collapse=" ")))
       best <- better
       best.progr <- c(best.progr, better$Trait.comb)
     }
  }
}

best.4traits <- corXY.ci %>% 
  filter(as.character(Trait.comb)==best.progr[length(best.progr)]) %>% 
  dplyr::select(trait1:trait7) %>% 
  mutate_all(~as.character(.))
best.4traits <- as.character(best.4traits[1,1:4])

### Create dataset with best combinations + all the one-way combinations
mydata.best <- mydata %>% 
  filter_at(.vars=vars(trait1:trait8), 
  #          .vars_predicate = all_vars(. %in% best$trait.name | is.na(.))) %>% 
            .vars_predicate = all_vars(. %in% traits.sign.alone | is.na(.))) %>% 
  #filter(ntraits <= length(best$trait.name)) %>% 
  filter(ntraits>1) %>% 
  filter(sign_plus==T) %>% 
  arrange(ntraits, Coef.obs) %>% 
  group_by(ntraits) %>% 
  slice(n()) %>% 
  ungroup() %>% 
  bind_rows(corXY.ci %>% 
        filter(run=="seq") %>% 
        filter(ntraits==1) %>% 
        filter(trait1 %in% traits.sign.alone)) %>% 
  arrange(ntraits, Coef.obs) %>% 
  mutate(seq=1:n()) %>% 
  mutate(sign_plus=factor(Trait.comb %in% best.progr))

write_csv(mydata.best %>% 
            dplyr::select(Trait.comb:sign_plus), 
          path = "_derived/Mesobromion/S5_BestSolutionTiers.csv")

### Graph of all the best combinations with text legend
(top.all <- ggplot(data=(mydata.best %>% 
               mutate(size0=.6+(as.numeric(sign_plus)-1)*.6)))   + 
         geom_segment(aes(x=q025, xend=q975, y=seq, yend=seq, col="a", 
                          lwd=size0)) + 
  geom_point(aes(x=Coef.obs, y=seq), pch=15) + 
  scale_y_continuous(breaks=mydata.best$seq, 
                     labels=mydata.best$Trait.comb, name=NULL)  +  
  scale_x_continuous(name="RD correlation") + 
  scale_size_identity() +
  theme_bw() + 
  theme(panel.grid.minor = element_blank(),
        axis.text = element_text(size=7), 
        legend.position = "none"))


tt2 <- ttheme_minimal(
  core = list(fg_params=list(cex = .7), 
              padding=unit(c(1, 1), "mm")),
  colhead = list(fg_params=list(cex = .7)),
  rowhead = list(fg_params=list(cex = .7)))

(topall.leg <- cowplot::plot_grid(top.all,
                                 tableGrob(trait.labs %>% 
                                             mutate(Code=1:n()) %>% 
                                             dplyr::select(Code, Trait=Short_english_name) %>% 
                                             filter(Trait %in% traits.sign.alone),
                                             theme=tt2, rows = NULL), 
                                 #tableGrob(trait.labs %>% 
                                #             mutate(Code=1:n()) %>% 
                                #             dplyr::select(Code, Trait=trait.name) %>% 
                                #             slice(33:n()), theme=tt2), 
                         nrow=1, rel_widths=c(0.70, 0.3)))
ggsave(filename = "_pics/Fig5_Best_AllCombinations_CI_pa.png", dpi=400, 
       width=6, height=3, topall.leg)


break()


###### 2.2 Presence/Absence data #### 
####### 2.2.1 Import and adjust dataset ####
### merge output from one-by-one and all combo of sign traits

### all traits taken alone 
myfilelist0 <- list.files(path="_derived/Mesobromion/PresAbs", pattern="HIDDENpa_[0-9]+_.RData", full.names = T)
dataFiles0 = purrr::map(myfilelist0, function(x){get(load(x))})
#load("_derived/Mesobromion/PresAbs/HIDDEN_round_11.RData")
corXY.alone = bind_rows(dataFiles0) %>% 
  as.tbl() %>% 
  distinct()
corXY.alone.ci <- get.ci(corXY.alone)
corXY.alone.ci <- corXY.alone.ci %>% 
  mutate(trait1=Trait.comb) %>% 
  mutate_at(.vars=vars(trait1),
            .funs=~factor(., 
                          levels=trait.labs$Trait.comb, 
                          labels=trait.labs$Short_english_name)) %>% 
  arrange(ntraits, Coef.obs) %>% 
  dplyr::select(Trait.comb, Test, n, ntraits, everything()) %>% 
  mutate(Trait.comb=NA)


### combo of sign traits 
myfilelist <- list.files(path="_derived/Mesobromion/PresAbs", pattern="HIDDENpresabs_[0-9]+_.RData", full.names = T)
dataFiles = purrr::map(myfilelist, function(x){get(load(x))})
#load("_derived/Mesobromion/PresAbs/HIDDEN_round_11.RData")
corXY.comb = bind_rows(dataFiles) %>% 
  as.tbl()

corXY.comb.ci <- get.ci(corXY.comb)
corXY.comb.ci <- corXY.comb.ci %>% 
  mutate(Trait.comb2=Trait.comb) %>% 
  #split strings of trait combinations and add labels
  separate(Trait.comb2, into=paste0("trait", 1:7)) %>% 
  mutate_at(.vars=vars(trait1:trait7),
            .funs=~factor(., 
                          levels=trait.labs.sign$Trait.comb, 
                          labels=trait.labs.sign$Short_english_name)) %>% 
  arrange(ntraits, Coef.obs) %>% 
  dplyr::select(Trait.comb, Test, n, ntraits, everything())


rm( dataFiles, dataFiles0)

### merge together
corXY.ci <- corXY.comb.ci %>% 
  bind_rows(corXY.alone.ci %>% 
              filter(!trait1 %in% trait.labs.sign$Short_english_name)) %>% 
  arrange(Coef.obs)

#### ____TO DO ########  




##### 3. Calculate CWM ####
#species <- read_delim("_data/Mesobromion/species.out.10perc.txt", delim="\t")
species.cov <- read_delim("_data/Mesobromion/species.v2.10perc.cov.txt", delim="\t")

CWM.wide <- species.cov %>% 
  pivot_longer(-RELEVE_NR, names_to = "species0", values_to = "rel.cov") %>% 
  as.tbl() %>% 
  filter(rel.cov>0) %>% 
  arrange(RELEVE_NR)  %>% 
  ## attach traits 
  left_join(traits %>% 
              rownames_to_column("species0"), 
            by="species0") %>% 
  group_by(RELEVE_NR) %>% 
  select_if(.predicate=~is.numeric(.)) %>%  # CWM calculated ONLY for numeric traits
  summarize_at(.vars = vars(any_of(traits.sign.alone)), #GF_Macrophan:Rosette), 
            .funs = list(~weighted.mean(., rel.cov, na.rm=T))) %>%
  dplyr::select(RELEVE_NR, order(colnames(.))) %>% 
  column_to_rownames("RELEVE_NR")

#### 4. PCA Graphs ####
library(vegan)
library(ggrepel)

##palette 
orange = "#d95f02"
oilgreen = "#1b9e77"
myblue = "#7570b3"


##from https://stackoverflow.com/questions/6862742/draw-a-circle-with-ggplot2
circleFun <- function(center = c(0,0),diameter = 1, npoints = 100){
  r = diameter / 2
  tt <- seq(0,2*pi,length.out = npoints)
  xx <- center[1] + r * cos(tt)
  yy <- center[2] + r * sin(tt)
  return(data.frame(x = xx, y = yy))
}
dat <- circleFun(diameter = 2, npoints = 100)
### 4.0 PCA of X (Fuzzy-weighted) matrix + CWMs ####
source("01b_MesobromionCluster.R")
W.fuzzy <- matrix.x(comm=species.cov %>% 
                      column_to_rownames("RELEVE_NR"), 
                    traits=traits %>% 
                      rownames_to_column("species0") %>% 
                      filter(species0 %in% colnames(species.cov)) %>% 
                      column_to_rownames("species0") %>% 
                      dplyr::select(all_of(traits.sign.alone)), 
                    scale = T)$matrix.X
pca.fuzz <- rda(W.fuzzy) 
varexpl <- round((pca.fuzz$CA$eig)/sum(pca.fuzz$CA$eig)*100,1)
scores.pca <- pca.fuzz$CA$u
cwm.cor <- cor(CWM.wide, scores.pca[,1:3], use = "pairwise.complete.obs")  #double check
env.cor <- cor(env %>% 
      dplyr::select(Temp, Prec, pH=PHIPHOX, C.org=ORCDRC), 
      scores.pca[,1:3]) #double check

myvectors <- as.data.frame(env.cor) %>% 
  rownames_to_column("mylab") %>% 
  mutate(category="Env") %>% 
  bind_rows(as.data.frame(cwm.cor) %>% 
              rownames_to_column("mylab") %>%
              mutate(category="Trait")) %>% 
  mutate(fontface0=ifelse(mylab %in% best.4traits, "bold", "italic")) %>% 
  mutate(category=as.factor(category)) %>% 
  mutate(mycol=ifelse(category=="Trait", oilgreen, orange))

basemap0 <- ggplot(data=as.data.frame(scores.pca*5)) + 
  theme_bw() + 
  scale_color_identity() + 
  scale_y_continuous(limits=c(-1, 1)) + 
  scale_x_continuous(limits=c(-1, 1)) +  coord_equal() + 
  theme(panel.grid = element_blank())

PCA.fuzz1_2 <- basemap0 + 
  geom_point(data=as.data.frame(pca.fuzz$CA$u[,1:3]*5), 
             aes(x=PC1, y=PC2), pch="+", size=2, alpha=0.8) + 
  geom_segment(data=myvectors, 
               aes(x=0, xend=PC1, y=0, yend=PC2, col=mycol), 
               arrow = arrow(length = unit(0.08, "inches")), alpha=0.8) +
  geom_path(data=dat,aes(x,y), col=gray(0.8), lwd=0.5) + #add correlation circle
  geom_label_repel(data=myvectors,# %>% 
               #mutate_if(~is.numeric(.), ~(.)*1.2),
             aes(x=PC1, y=PC2, label=mylab, col=mycol, fontface=fontface0), size=2, 
             position = position_dodge(1), segment.alpha=0.8, segment.colour=gray(0.7)) +
  xlab(paste("PC1 (", varexpl[1], "%)", sep="")) + 
  ylab(paste("PC2 (", varexpl[2], "%)", sep=""))

PCA.fuzz2_3 <- basemap0 + 
  geom_point(data=as.data.frame(pca.fuzz$CA$u[,1:3]*5), 
             aes(x=PC2, y=PC3), pch="+", size=2, alpha=0.8) + 
  geom_segment(data=myvectors, 
               aes(x=0, xend=PC2, y=0, yend=PC3, col=mycol), 
               arrow = arrow(length = unit(0.08, "inches")), alpha=0.8) +
  geom_path(data=dat,aes(x,y), col=gray(0.8), lwd=0.5) + #add correlation circle
  geom_label_repel(data=myvectors,# %>% 
               #mutate_if(~is.numeric(.), ~(.)*1.2),
             aes(x=PC2, y=PC3, label=mylab, col=mycol, fontface=fontface0), size=2, 
             position = position_dodge(1), segment.alpha=0.8, segment.colour=gray(0.7)) +
  xlab(paste("PC2 (", varexpl[2], "%)", sep="")) + 
  ylab(paste("PC3 (", varexpl[3], "%)", sep=""))

PC_fuzzy <- cowplot::plot_grid(PCA.fuzz1_2,PCA.fuzz2_3, nrow=1)
ggsave("_pics/FigSXXX_PC_Fuzzy_1-3.png", width=10, height=5, dpi=300, last_plot())

#### 4.0b Alternative showing species scores ####
tmp <- as.data.frame(pca.fuzz$CA$v[,1:3]*7) %>% 
  mutate(species0=colnames(species.cov)[-1]) %>% 
  mutate(species=species0) %>% 
  separate(species0, sep="_", into=c("Gen", "Spe")) %>% 
  mutate(Gen=substr(Gen, 1, 3)) %>% 
  mutate(Spe=substr(Spe, 1, 3)) %>% 
  mutate(labels=paste(Gen, Spe, sep="_"))


PCAfuzz1_2.sp <- basemap0 %+% tmp + 
  geom_text(aes(x=PC1, y=PC2, label=labels), size=2, alpha=0.8) + 
  geom_segment(data=myvectors, 
               aes(x=0, xend=PC1, y=0, yend=PC2, col=mycol), 
               arrow = arrow(length = unit(0.08, "inches")), alpha=0.8) +
  geom_path(data=dat,aes(x,y), col=gray(0.8), lwd=0.5) + #add correlation circle
  geom_label_repel(data=myvectors,
             aes(x=PC1, y=PC2, label=mylab, col=mycol, fontface=fontface0), size=2, 
             position = position_dodge(1), segment.alpha=0.8, segment.colour=gray(0.7)) +
  xlab(paste("PC1 (", varexpl[1], "%)", sep="")) + 
  ylab(paste("PC2 (", varexpl[2], "%)", sep=""))

PCAfuzz2_3.sp <- basemap0 %+% tmp + 
  geom_text(aes(x=PC2, y=PC3, label=labels), size=2, alpha=0.8) + 
  geom_segment(data=myvectors, 
               aes(x=0, xend=PC2, y=0, yend=PC3, col=mycol), 
               arrow = arrow(length = unit(0.08, "inches")), alpha=0.8) +
  geom_path(data=dat,aes(x,y), col=gray(0.8), lwd=0.5) + #add correlation circle
  geom_label_repel(data=myvectors, 
                   aes(x=PC2, y=PC3, label=mylab, col=mycol, fontface=fontface0), size=2, 
                   position = position_dodge(1), segment.alpha=0.8, segment.colour=gray(0.7), segment.size = 0.5) +
  xlab(paste("PC2 (", varexpl[2], "%)", sep="")) + 
  ylab(paste("PC3 (", varexpl[3], "%)", sep="")) 


ggsave("_pics/FigSXXXa_PCA_Fuzzy_1-2_wSpecies.png", width=8, height=8, dpi=300, PCAfuzz1_2.sp)
ggsave("_pics/FigSXXXb_PCA_Fuzzy_2-3_wSpecies.png", width=8, height=8, dpi=300, PCAfuzz2_3.sp)







#### 4.1 PCA of Y (Bealls) matrix + CWM ####
W.beals <- as.data.frame(beals(species.cov %>% 
                                 column_to_rownames("RELEVE_NR")  %>% 
                                 mutate_all(~(.>0)*1),  #transform to p\a
                         include=T, type=2))
write.table(W.beals, sep="\t", file="_derived/Mesobromion/MatrixY_Beals.csv")
pca.out <- rda(W.beals)
varexpl <- round((pca.out$CA$eig)/sum(pca.out$CA$eig)*100,1)
cwms.envfit <- envfit(pca.out, CWM.wide, na.rm = T, choices = 1:5)
env.envfit <- envfit(pca.out, env %>% 
                       dplyr::select(Temp, Prec, pH=PHIPHOX, C.org=ORCDRC), choices=1:5)

### Transform to correlations and sink envfits
### see https://www.davidzeleny.net/anadat-r/doku.php/en:suppl_vars_examples for procedure
scores.pca <- pca.out$CA$u
arrow_heads <- cwms.envfit$vectors$arrows  # extracts matrix of coordinates of arrow heads from ef
r2 <- cwms.envfit$vectors$r                # extracts vector of r2 for each env. variable
cwms.cor <- arrow_heads * sqrt (r2)
cor(CWM.wide, scores.pca[,1:5])  #double check


arrow_heads <- env.envfit$vectors$arrows  # extracts matrix of coordinates of arrow heads from ef
r2 <- env.envfit$vectors$r                # extracts vector of r2 for each env. variable
env.cor <- arrow_heads * sqrt (r2)
cor(env %>% 
      dplyr::select(Temp, Prec, pH=PHIPHOX, C.org=ORCDRC), scores.pca[,1:5]) #double check

fuzz.cor <- cor(pca.fuzz$CA$u[,1:3], scores.pca[,1:5])

sink("_derived/Mesobromion/EnvFit_CWMs_env.txt")
cwms.cor
env.cor
fuzz.cor
sink()


myvectors <- as.data.frame(env.cor) %>% 
  rownames_to_column("mylab") %>% 
  mutate(category="Env") %>% 
  bind_rows(as.data.frame(cwms.cor) %>% 
              rownames_to_column("mylab") %>%
              mutate(category="Trait")) %>% 
  bind_rows(as.data.frame(fuzz.cor) %>% 
              rownames_to_column("mylab") %>%
              mutate(category="Fuzzy-Weighted")) %>% 
  mutate(fontface0=ifelse(mylab %in% best.4traits, "bold", "italic")) %>% 
  mutate(category=as.factor(category)) %>% 
  mutate(mycol=ifelse(category=="Trait", oilgreen, orange)) %>%
  mutate(mycol=ifelse(category=="Fuzzy-Weighted", myblue, mycol))
  
  

basemap0 <- ggplot(data=as.data.frame(pca.out$CA$u[,1:4]*5)) + 
  theme_bw() + 
  scale_color_identity() + 
  scale_y_continuous(limits=c(-1, 1)) + 
  scale_x_continuous(limits=c(-1, 1)) +  coord_equal() + 
  theme(panel.grid = element_blank())
  

PCA1_2 <- basemap0 + 
  geom_point(data=as.data.frame(pca.out$CA$u[,1:2]*5), 
             aes(x=PC1, y=PC2), pch="+", size=2, alpha=0.8) + 
  geom_segment(data=myvectors, 
               aes(x=0, xend=PC1, y=0, yend=PC2, col=mycol), 
               arrow = arrow(length = unit(0.08, "inches")), alpha=0.8) +
  geom_path(data=dat,aes(x,y), col=gray(0.8), lwd=0.5) + #add correlation circle
  geom_label_repel(data=myvectors,
             aes(x=PC1, y=PC2, label=mylab, col=mycol, fontface=fontface0), size=2, 
             position = position_dodge(1), segment.alpha=0.5, segment.colour=gray(0.8)) +
  xlab(paste("PC1 (", varexpl[1], "%)", sep="")) + 
  ylab(paste("PC2 (", varexpl[2], "%)", sep=""))


PCA3_4 <- basemap0 + 
  geom_point(data=as.data.frame(pca.out$CA$u[,3:4]*5), 
             aes(x=PC3, y=PC4), pch="+", size=2, alpha=0.8) + 
  geom_segment(data=myvectors, 
               aes(x=0, xend=PC3, y=0, yend=PC4, col=mycol), 
               arrow = arrow(length = unit(0.08, "inches")), alpha=0.8) +
  geom_path(data=dat,aes(x,y), col=gray(0.8), lwd=0.5) + #add correlation circle
  geom_label_repel(data=myvectors, 
             aes(x=PC3, y=PC4, label=mylab, col=mycol, fontface=fontface0), size=2, 
             position = position_dodge(1), segment.alpha=0.8, segment.colour=gray(0.7), segment.size = 0.5) +
  xlab(paste("PC3 (", varexpl[3], "%)", sep="")) + 
  ylab(paste("PC4 (", varexpl[4], "%)", sep="")) 

PC_beals <- cowplot::plot_grid(PCA1_2,PCA3_4, nrow=1)

ggsave("_pics/Fig6_PC_Beals_1-4.png", width=10, height=5, dpi=300, last_plot())


#### 4.1b Alternative showing species scores ####
tmp <- as.data.frame(pca.out$CA$v[,1:4]*5) %>% 
  mutate(species0=rownames(pca.out$CA$v)) %>% 
  mutate(species=species0) %>% 
  separate(species0, sep="_", into=c("Gen", "Spe")) %>% 
  mutate(Gen=substr(Gen, 1, 3)) %>% 
  mutate(Spe=substr(Spe, 1, 3)) %>% 
  mutate(labels=paste(Gen, Spe, sep="_"))


PCA1_2.sp <- basemap0 %+% tmp + 
  geom_text(aes(x=PC1, y=PC2, label=labels), size=2, alpha=0.8) + 
  geom_segment(data=myvectors, 
               aes(x=0, xend=PC1, y=0, yend=PC2, col=mycol), 
               arrow = arrow(length = unit(0.08, "inches")), alpha=0.8) +
  geom_path(data=dat,aes(x,y), col=gray(0.8), lwd=0.5) + #add correlation circle
  geom_label_repel(data=myvectors,
             aes(x=PC1, y=PC2, label=mylab, col=mycol, fontface=fontface0), size=2, 
             position = position_dodge(1), segment.alpha=0.5, segment.colour=gray(0.8)) +
  xlab(paste("PC1 (", varexpl[1], "%)", sep="")) + 
  ylab(paste("PC2 (", varexpl[2], "%)", sep=""))

PCA3_4.sp <- basemap0 %+% tmp + 
  geom_text(aes(x=PC3, y=PC4, label=labels), size=2, alpha=0.8) + 
  geom_segment(data=myvectors, 
               aes(x=0, xend=PC3, y=0, yend=PC4, col=mycol), 
               arrow = arrow(length = unit(0.08, "inches")), alpha=0.8) +
  geom_path(data=dat,aes(x,y), col=gray(0.8), lwd=0.5) + #add correlation circle
  geom_label_repel(data=myvectors, 
                   aes(x=PC3, y=PC4, label=mylab, col=mycol, fontface=fontface0), size=2, 
                   position = position_dodge(1), segment.alpha=0.8, segment.colour=gray(0.7), segment.size = 0.5) +
  xlab(paste("PC3 (", varexpl[3], "%)", sep="")) + 
  ylab(paste("PC4 (", varexpl[4], "%)", sep="")) 


ggsave("_pics/Fig6a_PCA_Traits_1-2_wSpecies.png", width=8, height=8, dpi=300, PCA1_2.sp)
ggsave("_pics/Fig6b_PCA_Traits_3-4_wSpecies.png", width=8, height=8, dpi=300, PCA3_4.sp)






# #### 4.2 PCA of CWMs #####
# CWM.pca <- vegan::rda(CWM.wide, scale=T)
# varexpl <- round(CWM.pca$CA$eig/sum(CWM.pca$CA$eig)*100,1)
# 
# ggplot() + 
#   geom_point(data=as.data.frame(CWM.pca$CA$u[,1:2]), 
#              aes(x=PC1, y=PC2), pch="+", size=2, alpha=0.8) + 
#   geom_segment(data=as.data.frame(CWM.pca$CA$v*2) %>% 
#                  rownames_to_column("Trait") %>% 
#                  mutate(in.try=ifelse(Trait %in% colnames(alltry), "Dark red", "Dark blue")), 
#                aes(x=0, xend=PC1, y=0, yend=PC2, col=in.try), arrow = arrow(length = unit(0.08, "inches")), alpha=0.8) +
#   geom_text(data=as.data.frame(CWM.pca$CA$v*2.1) %>% 
#               rownames_to_column("Trait") %>% 
#               mutate(in.try=ifelse(Trait %in% colnames(alltry), "Dark red", "Dark blue")), 
#             aes(x=PC1, y=PC2, label=Trait, col=in.try),  size=3 ) +
#   scale_color_identity() + 
#   xlab(paste("PC1 (", varexpl[1], "%)", sep="")) + 
#   ylab(paste("PC2 (", varexpl[2], "%)", sep="")) + 
#   theme_bw() + 
#   theme(panel.grid = element_blank()) + 
#   title("PCA of CWMs")

#### 4.3 PCA of individual traits #####
# assign weights to traits [Growth forms and root structures are coded as binary, but should be downweighted]
#myweights <- c(rep(1/9, 9), rep(1/17, 17), rep(1, 26))
#traits.gowdis <- FD::gowdis(traits, w=myweights, ord="podani")
data2 <- traits %>% 
  dplyr::select_if(.predicate = ~is.numeric(.)) %>%  ### CAUTION -- ONLY NUMERIC TRAITS SHOWN
  dplyr::select(any_of(traits.sign.alone)) %>% 
  rownames_to_column("species") %>% 
  filter(species %in% colnames(species.cov)) %>% 
  column_to_rownames("species")
  
corr1 <- cor(data2, use="pairwise.complete.obs")
pca2 <- princomp(covmat=corr1)
#plot(pca2$loadings[,2]~pca2$loadings[,1])
#text(pca2$loadings[,1], pca2$loadings[,2], dimnames(pca2$loadings)[[1]])
#arrows(rep(0,8),rep(0,8),pca2$loadings[,1],pca2$loadings[,2], length=0.1)
zdat <- scale(data2) #this is just to standardize the original data, M = 0, SD =1
e1 <- eigen(corr1) #solving for the eigenvalues and eigenvectors from the correlation matrix
varexpl <- round((e1$values)/sum(e1$values)*100,1)
pca.scores<- zdat %*% e1$vectors #scaled values x vectors
pca.scores <- pca.scores[,1:5]
colnames(pca.scores)<-c('pca1','pca2','pca3','pca4','pca5') #just quickly naming the columns

dat <- circleFun(diameter = 2, npoints = 100) 

baseplot <- ggplot(data=as.data.frame(pca.scores*.2)) + 
  scale_color_identity() + 
  coord_equal(xlim = c(-1, 1), ylim=c(-1, 1)) +
  xlab(paste("PC1 (", varexpl[1], "%)", sep="")) + 
  ylab(paste("PC2 (", varexpl[2], "%)", sep="")) + 
  theme_bw() + 
  theme(panel.grid = element_blank())

PCA.t1 <- baseplot +
  geom_point(aes(x=pca1, y=pca2), pch="+", size=2, alpha=0.8) + 
  geom_segment(data=as.data.frame(pca2$loadings[,1:5]), 
               aes(x=0, xend=Comp.1, y=0, yend=Comp.2, col=oilgreen), 
               arrow = arrow(length = unit(0.08, "inches")), alpha=0.8) +
  geom_path(data=dat,aes(x,y), col=gray(0.8), lwd=0.5) + #add correlation circle
  geom_label_repel(data=as.data.frame(pca2$loadings[,1:5]) %>% 
               rownames_to_column("Trait") %>% 
               mutate(fontface0=ifelse(Trait %in% best.4traits, "bold", "italic")), 
             aes(x=Comp.1, y=Comp.2, label=Trait, col=oilgreen, fontface=fontface0),  size=2, 
             position = position_dodge(2),segment.alpha=0.5, segment.colour=gray(0.8))
#ggtitle("PCoA of species-level traits") 

PCA.t2 <- baseplot +
  geom_point(aes(x=pca3, y=pca4), pch="+", size=2, alpha=0.8) + 
  geom_segment(data=as.data.frame(pca2$loadings[,1:5]), 
               aes(x=0, xend=Comp.3, y=0, yend=Comp.4, col=oilgreen), 
               arrow = arrow(length = unit(0.08, "inches")), alpha=0.8) +
  geom_path(data=dat,aes(x,y), col=gray(0.8), lwd=0.5) + #add correlation circle
  geom_label_repel(data=as.data.frame(pca2$loadings[,1:5]) %>%
               #geom_label(data=as.data.frame(pca2$loadings[,1:5]*8) %>% 
               rownames_to_column("Trait") %>% 
               mutate(fontface0=ifelse(Trait %in% best.4traits, "bold", "italic")), 
             aes(x=Comp.3, y=Comp.4, label=Trait, col=oilgreen, fontface=fontface0),  size=2, 
             position = position_dodge(2),segment.alpha=0.5, segment.colour=gray(0.8))  + 
  xlab(paste("PC3 (", varexpl[3], "%)", sep="")) + 
  ylab(paste("PC4 (", varexpl[4], "%)", sep=""))

PC_traits <- cowplot::plot_grid(PCA.t1, PCA.t2, nrow=1)

ggsave("_pics/S6_PCA_Traits_1-4_only7.png", width=10, height=5, dpi=300, PC_traits)

##### 4.3b Alternative version of figS6, showing the species ####
tmp <- as.data.frame(pca.scores[,1:4]*.2) %>% 
  mutate(species0=rownames(pca.scores)) %>% 
  mutate(species=species0) %>% 
  separate(species0, sep="_", into=c("Gen", "Spe")) %>% 
  mutate(Gen=substr(Gen, 1, 3)) %>% 
  mutate(Spe=substr(Spe, 1, 3)) %>% 
  mutate(labels=paste(Gen, Spe, sep="_"))


PCA.t1.sp <- baseplot %+% tmp + 
  geom_text(aes(x=pca1, y=pca2, label=labels), size=2, alpha=0.7) + 
  geom_segment(data=as.data.frame(pca2$loadings[,1:5]), 
               aes(x=0, xend=Comp.1, y=0, yend=Comp.2, col=oilgreen), 
               arrow = arrow(length = unit(0.08, "inches")), alpha=0.8) +
  geom_path(data=dat,aes(x,y), col=gray(0.8), lwd=0.5) + #add correlation circle
  geom_label_repel(data=as.data.frame(pca2$loadings[,1:5]) %>% 
                     rownames_to_column("Trait") %>% 
                     mutate(fontface0=ifelse(Trait %in% best.4traits, "bold", "italic")), 
                   aes(x=Comp.1, y=Comp.2, label=Trait, col=oilgreen, fontface=fontface0),  size=2, 
                   position = position_dodge(2),segment.alpha=0.5, segment.colour=gray(0.8))

PCA.t2.sp <- baseplot %+% tmp + 
  geom_text(aes(x=pca3, y=pca4, label=labels), size=2, alpha=0.7) + 
  geom_segment(data=as.data.frame(pca2$loadings[,1:5]), 
               aes(x=0, xend=Comp.3, y=0, yend=Comp.4, col=oilgreen), 
               arrow = arrow(length = unit(0.08, "inches")), alpha=0.8) +
  geom_path(data=dat,aes(x,y), col=gray(0.8), lwd=0.5) + #add correlation circle
  geom_label_repel(data=as.data.frame(pca2$loadings[,1:5]) %>%
                     #geom_label(data=as.data.frame(pca2$loadings[,1:5]*8) %>% 
                     rownames_to_column("Trait") %>% 
                     mutate(fontface0=ifelse(Trait %in% best.4traits, "bold", "italic")), 
                   aes(x=Comp.3, y=Comp.4, label=Trait, col=oilgreen, fontface=fontface0),  size=2, 
                   position = position_dodge(2),segment.alpha=0.5, segment.colour=gray(0.8)) + 
  xlab(paste("PC3 (", varexpl[3], "%)", sep="")) + 
  ylab(paste("PC4 (", varexpl[4], "%)", sep=""))

ggsave("_pics/S6a_PCA_Traits_1-2_wSpecies.png", width=8, height=8, dpi=300, PCA.t1.sp)
ggsave("_pics/S6b_PCA_Traits_3-4_wSpecies.png", width=8, height=8, dpi=300, PCA.t2.sp)

## Create list of species labels
write_delim(tmp %>% 
              dplyr::select(species, label=labels), 
            path = "_derived/Mesobromion/SpeciesList.txt")





#### 5 Map of Plot distribution #####
library(rgdal)
library(sp)
library(sf)
coords <- read_delim(file = "_data/Mesobromion/Mes2_somecoordinates.csv", delim = ";")

env <- read_delim(file = "_data/Mesobromion/env.10perc.txt", delim = "\t")

env0 <- read_delim("_data/Mesobromion/GVRD_MES2_site.csv", delim = ",")
#header   <- "/data/sPlot/users/Francesco/Project_11/Germany/_data/tvhabita.dbf"
env.all  <- env0 %>% 
  left_join(coords %>% 
              dplyr::select(RELEVE_NR=MES2_releve_nr., 
                            LON=DD_X_, 
                            LAT=DD_Y_),
            by="RELEVE_NR") %>% 
  filter(!is.na(LAT)) %>%
  filter(!(LAT==0 | LON==0)) 


DE_NUTS1 <- readOGR(dsn="/data/sPlot/users/Francesco/Project_11/Germany/_data/Spatial", layer="Germany_LVL1_WGS84")
DE_NUTS_sf <- DE_NUTS1 %>% 
  st_as_sf()

env.sf <- SpatialPointsDataFrame(coords=env %>% dplyr::select(LON, LAT), 
                                 data=env %>% dplyr::select(-LON, -LAT), 
                                 proj4string = raster::crs(DE_NUTS1)) %>% 
  st_as_sf()

env.all.sf <- SpatialPointsDataFrame(coords=env.all %>% dplyr::select(LON, LAT), 
                                 data=env.all %>% dplyr::select(-LON, -LAT), 
                                 proj4string = raster::crs(DE_NUTS1)) %>% 
  st_as_sf()


(basemap2 <- ggplot(data=DE_NUTS_sf) + 
  geom_sf(col="darkgrey", lwd=0.5, fill="white", alpha=0.5)+
  geom_sf(data=env.all.sf, col=gray(0.5), size=1) + 
  geom_sf(data=env.sf, col="red", alpha=0.5, size=1) + 
  #geom_polygon(col="darkgrey", lwd=0.5, fill="white")+
  coord_sf() + 
  theme_bw()
)

ggsave(filename="_pics/PlotDistribution.png", height
       =8, width=6, dpi=300, basemap2)




#### 6 Correlation matrices ####
#### 6.1 Trait level #####
library(corrplot)
traits7 <- traits.cov %>% 
  rownames_to_column("species") %>% 
  filter(species %in% colnames(species.cov)) %>% 
  column_to_rownames("species") %>% 
  dplyr::select(any_of(traits.sign.alone)) %>% 
  dplyr::select(sort(tidyselect::peek_vars())) %>% 
  relocate(all_of(best.2traits), everything())

res <- cor(traits7, use = "pairwise.complete.obs")
png(file="_pics/S7_Correlations_Trait.png", width=8, height=6.5, units = "in", res=300)
corrplot(res, type = "upper", 
         tl.col = "black", tl.srt = 45, number.cex=0.6, addCoef.col = "black", diag=F)
dev.off()


#### 6.2 CWM level ####
res2 <- cor(CWM.wide %>% 
             dplyr::select(sort(tidyselect::peek_vars())) %>% 
             relocate(all_of(best.2traits), everything()))
png(file="_pics/S8_Correlations_CWMs.png", width=8, height=6.5, units = "in", res=300)
corrplot(res2, type = "upper", 
         tl.col = "black", tl.srt = 45, number.cex=0.6, addCoef.col = "black", diag=F)
dev.off()








